package data.missions.dara_shiptests;

import com.fs.starfarer.api.fleet.FleetGoal;
import com.fs.starfarer.api.fleet.FleetMemberType;
import com.fs.starfarer.api.mission.FleetSide;
import com.fs.starfarer.api.mission.MissionDefinitionAPI;
import com.fs.starfarer.api.mission.MissionDefinitionPlugin;

public class MissionDefinition implements MissionDefinitionPlugin
{

    @Override
    public void defineMission(MissionDefinitionAPI api)
    {
        // Set up the fleets so we can add ships and fighter wings to them.
        // In this scenario, the fleets are attacking each other, but
        // in other scenarios, a fleet may be defending or trying to escape
        api.initFleet(FleetSide.PLAYER, "ISS", FleetGoal.ATTACK, false, 27);
        api.initFleet(FleetSide.ENEMY, "ISS", FleetGoal.ATTACK, true);

        // Set a small blurb for each fleet that shows up on the mission detail and
        // mission results screens to identify each side.
        api.setFleetTagline(FleetSide.PLAYER, "Your Forces");
        api.setFleetTagline(FleetSide.ENEMY, "Enemy Forces");

        // These show up as items in the bulleted list under 
        // "Tactical Objectives" on the mission detail screen
        api.addBriefingItem("Experiment with and test the added ships");

        // Friendly ships
        api.addToFleet(FleetSide.PLAYER, "dara_vendetta_Standard", FleetMemberType.SHIP, true);
        api.addToFleet(FleetSide.PLAYER, "dara_vendetta_xiv_Elite", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_starlifter_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_outlander_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_harrier_AD", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_retribution_CS", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_retribution_lp_Assault", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_bull_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_lysander_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_sturmovik_Strike", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_sturmovik_s_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_sturmovik_mkii_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_vagrant_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_vagrant_Support", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_mousetrap_Strike", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_manta_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_manta_lp_Attack", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_manta_pirates_Assault", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_gypsymoth_Scav", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_seraph_CS", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_constellation_Assault", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_incendere_Siege", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_insurgent_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_acanthina_Missile", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_acanthina_Drone", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_acanthina_Freighter", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_acanthina_heg_Missile", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_acanthina_Gunship", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_quoin_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_prophecy_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_prophecy_pirates_Elite", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_gladiator_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_gladiator_f_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_trebuchet_GroundOps", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_trebuchet_pirates_Assault", FleetMemberType.SHIP, false);
        //api.addToFleet(FleetSide.PLAYER, "dara_taurus_d_Attack", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_triton_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_katrina_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_spectacle_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_wren_Balanced", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_wren_xiv_Escort", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_wren_pirates_CS", FleetMemberType.SHIP, false);
        //api.addToFleet(FleetSide.PLAYER, "dara_sparrow_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_mirage_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_arrow_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_arrow_heg_Assault", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_arrow_lp_Attack", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_arrow_stealth_Raider", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_junker_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_brawler_carrier_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_dram_heg_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.PLAYER, "dara_gemini_civ_Standard", FleetMemberType.SHIP, false);
        //api.addToFleet(FleetSide.PLAYER, "dara_de_sensorbuoy_Standard", FleetMemberType.SHIP, false);

        // Enemy forces
        api.addToFleet(FleetSide.ENEMY, "onslaught_Standard", FleetMemberType.SHIP, true);
        api.addToFleet(FleetSide.ENEMY, "falcon_d_CS", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.ENEMY, "condor_Support", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.ENEMY, "hammerhead_d_CS", FleetMemberType.SHIP, false);
        //api.addToFleet(FleetSide.ENEMY, "talon_wing", FleetMemberType.FIGHTER_WING, false);
        //api.addToFleet(FleetSide.ENEMY, "piranha_wing", FleetMemberType.FIGHTER_WING, false);
        //api.addToFleet(FleetSide.ENEMY, "cerberus_d_pirates_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.ENEMY, "hound_d_pirates_Standard", FleetMemberType.SHIP, false);
        api.addToFleet(FleetSide.ENEMY, "lasher_d_CS", FleetMemberType.SHIP, false);

        // Set up the map.
        float width = 12000f;
        float height = 12000f;
        api.initMap((float) -width / 2f, (float) width / 2f, (float) -height / 2f, (float) height / 2f);

        float minX = -width / 2;
        float minY = -height / 2;

        // Add an asteroid field
        api.addAsteroidField(minX, minY + height / 2, 0, 8000f, 20f, 70f, 100);

	// Add objectives. These can be captured by each side
	// and provide stat bonuses and extra command points to
	// bring in reinforcements.
	// Reinforcements only matter for large fleets - in this
	// case, assuming a 100 command point battle size,
	// both fleets will be able to deploy fully right away.
	//api.addObjective(500, -4000, "dara_minefield");

        api.addPlanet(0, 0, 50f, "star_yellow", 250f, true);
    }
}
