package data.scripts.shipsystems.ai;

// [!] This AI script is based on that used by the Ship&Weapon Pack's Hexblade fighter, specifically
// the Invocation system. Full credit goes to Dark.Revenant who allowed me to replicate the script,
// and to MesoTronik who helped me understand how it works.
// This script is licensed under the same license as in the Ship&Weapon Pack mod.

import com.fs.starfarer.api.combat.CombatEngineAPI;
import com.fs.starfarer.api.combat.ShipAPI;
import com.fs.starfarer.api.combat.ShipSystemAIScript;
import com.fs.starfarer.api.combat.ShipSystemAPI;
import com.fs.starfarer.api.combat.ShipwideAIFlags;
import com.fs.starfarer.api.util.IntervalUtil;
import org.lazywizard.lazylib.MathUtils;		// aaaaaaaaaaa LazyLib stuff
import org.lazywizard.lazylib.VectorUtils;
import org.lazywizard.lazylib.combat.AIUtils;
import org.lwjgl.util.vector.Vector2f;
import java.awt.Color;

public class dara_DetonateAI implements ShipSystemAIScript {

    private CombatEngineAPI engine;	// This just checks that we're actually in a battle.
    private ShipAPI ship;               // And this checks that we're looking at a ship.

    private final IntervalUtil tracker = new IntervalUtil(0.5f, 1.0f);
        // A random interval between 0.5 and 1.0 seconds. Randomised to ensure minor randomness in when
        // the fighter chooses to use the system, and to not hurt game performance.
    private final int delayDetonation = 1;  // Number of passes the ship must make before using the system.
    private int delayCount = 0;
    private static final Color COLOR = new Color(255,255,255,255);

    @Override
    public void advance(float amount, Vector2f missileDangerDir, Vector2f collisionDangerDir, ShipAPI target) {
        if (engine.isPaused()) {	// If the game is paused, skip everything below this point.
            return;
        }

        tracker.advance(amount);	// Advance until the given interval has elapsed, then continue.

        if (tracker.intervalElapsed()) {
            if (!AIUtils.canUseSystemThisFrame(ship)) {     // If the fighter cannot use the system this frame, skip everything below this point.
                return;                                     // Presumably it cannot use the system if it is, say, overloaded, or at too high
                                                            // a flux level, or in the middle of its takeoff/landing animation perhaps?
            }
            

            boolean pointedAtTarget = false;	// Mark the fighter as "not ready" before testing if it has a target.
            if (target == null) {
                target = ship.getShipTarget();
                    // If no target is recorded by the script, record the fighter's current target.
            }
            if (target == null && ship.getWing() != null && ship.getWing().getLeader() != null) {
                target = ship.getWing().getLeader().getShipTarget();
                    // If still no target is recorded, record the current wing leader's target.
                    // Presumably this happens when the selected fighter is not the leader and has no target of its own.
            }
            if (target != null && target.isAlive()) {
                //float shipVel = VectorUtils.getAngle(new Vector2f(), ship.getVelocity());
                float shipFacing = ship.getFacing();
                //float targVel = VectorUtils.getAngle(new Vector2f(), target.getVelocity());
                float angleToTarget = VectorUtils.getAngle(ship.getLocation(), target.getLocation());
                
                //float diff = (Math.abs(shipVel - targVel));
                //diff = diff / 2f;
                //float aimVel = 0f;
                //if (shipVel > targVel) {
                //    aimVel = shipVel - diff;
                //} else {
                //    aimVel = targVel - diff;
                //}
                
                if (delayCount < delayDetonation && MathUtils.getDistance(ship, target) < 200f) {
                    delayCount += 1;
                    // If the fighter is less than 200 units away from its target, add 1 to the number of
                    // successful "passes" it has made.
                    
                    //engine.addFloatingText(ship.getLocation(),
                    //    "Delays: " + (int) delayCount,
                    //    28f,
                    //    COLOR,
                    //    null,
                    //    2f,
                    //    5f);
                }
                
                if (MathUtils.getShortestRotation(angleToTarget, shipFacing) <= 30f
                        && MathUtils.getDistance(ship, target) <= 1000f
                        && MathUtils.getDistance(ship, target) >= 200f) {
                    pointedAtTarget = true;
                    // If the target is between 200 and 1000 units away from its target, and pointed roughly at it
                    // (within a forward arc of 60 degrees), mark it as ready to use.
                }
            }
            

            if (pointedAtTarget && delayCount >= delayDetonation) {	
                // If the fighter is in the right place and has completed the preset number
                // of passes, then activate the system.
                ship.useSystem();
            }
        }
    }

    @Override
    public void init(ShipAPI ship, ShipSystemAPI system, ShipwideAIFlags flags, CombatEngineAPI engine) {
        this.ship = ship;
        this.engine = engine;
    }
}
